@@ -15,8 +15,7 @@ factory_gt <- function(tab,
                        output_format = "gt",
                        output_file = NULL,
                        ...) {
-
-  insight::check_if_installed("gt", minimum_version = "0.5.0")
+  insight::check_if_installed("gt", minimum_version = "0.11.1")
 
   # compute spans
   span_list <- get_span_gt(tab)
@@ -33,11 +32,11 @@ factory_gt <- function(tab,
 
   # theme
   theme_ms <- getOption("modelsummary_theme_gt",
-                        default = theme_ms_gt)
+    default = theme_ms_gt)
   out <- theme_ms(out,
-                  output_format = output_format,
-                  hrule = hrule,
-                  hgroup = hgroup)
+    output_format = output_format,
+    hrule = hrule,
+    hgroup = hgroup)
 
   # user-supplied notes at the bottom of table
   if (!is.null(notes)) {
@@ -49,28 +48,30 @@ factory_gt <- function(tab,
   if (length(span_list) > 0) {
     for (s in span_list) {
       out <- gt::tab_spanner(out,
-                             label = s$label,
-                             columns = tidyselect::all_of(s$columns),
-                             level = s$level)
+        label = s$label,
+        columns = tidyselect::all_of(s$columns),
+        level = s$level)
     }
   }
 
   # column alignment
   if (!is.null(align)) {
-    left <- grep('l', align)
-    center <- grep('c', align)
-    right <- grep('r', align)
+    left <- grep("l", align)
+    center <- grep("c", align)
+    right <- grep("r", align)
     out <- gt::cols_align(
-      out, align = 'center', columns = tidyselect::all_of(center))
+      out,
+      align = "center", columns = tidyselect::all_of(center))
     out <- gt::cols_align(
-      out, align = 'left', columns = tidyselect::all_of(left))
+      out,
+      align = "left", columns = tidyselect::all_of(left))
     out <- gt::cols_align(
-      out, align = 'right', column = tidyselect::all_of(right))
+      out,
+      align = "right", column = tidyselect::all_of(right))
   }
 
   # output
   if (is.null(output_file)) {
-
     if (identical(output_format, "html")) {
       out <- gt::as_raw_html(out)
     }
@@ -80,7 +81,7 @@ factory_gt <- function(tab,
     }
 
     if (!is.null(getOption("modelsummary_orgmode")) &&
-        output_format %in% c("html", "latex")) {
+      output_format %in% c("html", "latex")) {
       out <- sprintf("#+BEGIN_EXPORT %s\n%s\n#+END_EXPORT", output_format, out)
       return(out)
     }
@@ -88,7 +89,6 @@ factory_gt <- function(tab,
     if (output_format %in% c("default", "gt")) {
       return(out)
     }
-
   } else {
     gt::gtsave(out, output_file)
   }
