@@ -6,9 +6,9 @@ using("tinysnapshot")
 mod <- lm(hp ~ mpg, data = mtcars)
 expect_snapshot_print(
     print_html(modelsummary(mod, gof_omit = ".*")),
-    "html-gof_omit") |> suppressWarnings()
+    "html-gof_omit.html") |> suppressWarnings()
 
 # PR 538
 mod <- lm(mpg ~ hp + factor(cyl), data = mtcars)
 tab <- msummary(mod, stars = TRUE, output = "html")
-expect_true(grepl("\\&lt", tab))
\ No newline at end of file
+expect_true(grepl("\\&lt", tab))
